%define upstream_name    Socket-GetAddrInfo
%define upstream_version 0.22
Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 20
BuildArch:  noarch

Summary:    RFC 2553's C<getaddrinfo> and C<getnameinfo>
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/authors/id/P/PE/PEVANS/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Exporter) >= 5.570.0
BuildRequires: perl(ExtUtils::CBuilder)
BuildRequires: perl(ExtUtils::CChecker) >= 0.60.0
BuildRequires: perl(Module::Build)
BuildRequires: perl(Module::Build::Compat)
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Socket) >= 2.1.0
BuildRequires: perl(Test::More)
BuildRequires: perl(ExtUtils::CChecker)
BuildRequires: perl-devel

%{?perl_default_filter}
BuildRequires: perl(Test::Warn)
%description
The RFC 2553 functions 'getaddrinfo' and 'getnameinfo' provide an
abstracted way to convert between a pair of host name/service name and
socket addresses, or vice versa. 'getaddrinfo' converts names into a set of
arguments to pass to the 'socket()' and 'connect()' syscalls, and
'getnameinfo' converts a socket address back into its host name/service
name pair.

These functions provide a useful interface for performing either of these
name resolution operation, without having to deal with IPv4/IPv6
transparency, or whether the underlying host can support IPv6 at all, or
other such issues. However, not all platforms can support the underlying
calls at the C layer, which means a dilemma for authors wishing to write
forward-compatible code. Either to support these functions, and cause the
code not to work on older platforms, or stick to the older "legacy"
resolvers such as 'gethostbyname()', which means the code becomes more
portable.

This module attempts to solve this problem, by detecting at compiletime
whether the underlying OS will support these functions, and only compiling
the XS code if it can. At runtime, when the module is loaded, if the XS
implementation is not available, emulations of the functions using the
legacy resolver functions instead. The emulations support the same
interface as the real functions, and behave as close as is reasonably
possible to emulate using the legacy resolvers. See below for details on
the limits of this emulation.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man3/*
%perl_vendorlib/*


%changelog
* Thu Jun 26 2025 umeabot <umeabot> 0.220.0-20.mga10
+ Revision: 2200670
- Mageia 10 Mass Rebuild

* Sun Mar 20 2022 umeabot <umeabot> 0.220.0-19.mga9
+ Revision: 1805679
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.220.0-18.mga8
+ Revision: 1497186
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Sep 19 2018 umeabot <umeabot> 0.220.0-17.mga7
+ Revision: 1271201
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.220.0-16.mga6
+ Revision: 1033206
- Rebuild for perl 5.22.2

* Sat Feb 20 2016 umeabot <umeabot> 0.220.0-15.mga6
+ Revision: 971500
- Mageia 6 Mass Rebuild

* Thu Oct 15 2015 tv <tv> 0.220.0-14.mga6
+ Revision: 891770
- make it noarch thus fixing empty debuginfo

* Sun Oct 19 2014 umeabot <umeabot> 0.220.0-13.mga5
+ Revision: 789151
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.220.0-12.mga5
+ Revision: 748846
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 0.220.0-11.mga5
+ Revision: 733380
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.220.0-10.mga5
+ Revision: 686204
- Mageia 5 Mass Rebuild

* Fri Jun 06 2014 jquelin <jquelin> 0.220.0-9.mga5
+ Revision: 633975
- perl 5.20 rebuild

* Thu Mar 20 2014 jquelin <jquelin> 0.220.0-8.mga5
+ Revision: 606109
- perl 5.18.2 rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.220.0-7.mga4
+ Revision: 525777
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 jquelin <jquelin> 0.220.0-6.mga4
+ Revision: 434510
- perl 5.18.0 rebuild

* Mon Mar 18 2013 jquelin <jquelin> 0.220.0-5.mga3
+ Revision: 403829
- perl 5.16.3 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.220.0-4.mga3
+ Revision: 372657
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 06 2012 jquelin <jquelin> 0.220.0-3.mga3
+ Revision: 315053
- perl 5.16.2 shebang rebuild

* Fri Aug 24 2012 jquelin <jquelin> 0.220.0-2.mga3
+ Revision: 283582
- perl 5.16.1 rebuild

* Tue Jun 05 2012 jquelin <jquelin> 0.220.0-1.mga3
+ Revision: 255439
- update to 0.22

* Mon Jun 04 2012 jquelin <jquelin> 0.210.0-4.mga3
+ Revision: 254312
- rebuild to fix new shebang with perl 5.16

* Fri Oct 14 2011 jquelin <jquelin> 0.210.0-3.mga2
+ Revision: 155137
- perl 5.14.2 rebuild

* Sun Jun 19 2011 jquelin <jquelin> 0.210.0-2.mga2
+ Revision: 109899
- rebuild script for perl 5.14.1

* Wed Jun 15 2011 jquelin <jquelin> 0.210.0-1.mga2
+ Revision: 107409
- update to 0.21

* Sun Jun 12 2011 sander85 <sander85> 0.200.0-2.mga2
+ Revision: 104969
- Rebuild for perl 5.14

* Thu Feb 17 2011 jquelin <jquelin> 0.200.0-1.mga1
+ Revision: 53206
- update to 0.20

* Sat Jan 22 2011 jquelin <jquelin> 0.190.0-1.mga1
+ Revision: 32388
- mageia rebuild
- imported package perl-Socket-GetAddrInfo


* Sat Oct 16 2010 Götz Waschk <waschk@mandriva.org> 0.190.0-1mdv2011.0
+ Revision: 585999
- update to new version 0.19

* Thu Sep 16 2010 Götz Waschk <waschk@mandriva.org> 0.180.0-1mdv2011.0
+ Revision: 578820
- update to new version 0.18

* Wed Sep 15 2010 Götz Waschk <waschk@mandriva.org> 0.170.0-1mdv2011.0
+ Revision: 578427
- update to new version 0.17

* Tue Jul 20 2010 Jérôme Quelin <jquelin@mandriva.org> 0.160.0-2mdv2011.0
+ Revision: 556145
- rebuild for perl 5.12

* Fri Jul 16 2010 Jérôme Quelin <jquelin@mandriva.org> 0.160.0-1mdv2011.0
+ Revision: 553974
- update to 0.16

* Sat Jan 30 2010 Götz Waschk <waschk@mandriva.org> 0.150.0-1mdv2010.1
+ Revision: 498481
- new version
- update deps

* Fri Dec 25 2009 Götz Waschk <waschk@mandriva.org> 0.140.0-1mdv2010.1
+ Revision: 482201
- new version
- fix source URL

  + Jérôme Quelin <jquelin@mandriva.org>
    - update to 0.13

* Mon Sep 14 2009 Götz Waschk <waschk@mandriva.org> 0.130.0-1mdv2010.0
+ Revision: 439392
- update build deps
- update to new version 0.13

* Mon Jun 29 2009 Götz Waschk <waschk@mandriva.org> 0.120.0-1mdv2010.0
+ Revision: 390466
- import perl-Socket-GetAddrInfo


* Mon Jun 29 2009 cpan2dist 0.12-1mdv
- initial mdv release, generated with cpan2dist

